==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DownloadingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DownloadingMultiScaleImageEventArgsDescription } from "./DownloadingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let DownloadingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DownloadingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DownloadingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DownloadingMultiScaleImageEventArgsDescriptionMetadata.c(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.k(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.ad("DownloadingMultiScaleImageEventArgs", () => new DownloadingMultiScaleImageEventArgsDescription());
            a.ac("DownloadingMultiScaleImageEventArgs", DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DownloadingMultiScaleImageEventArgsDescriptionMetadata, 'DownloadingMultiScaleImageEventArgsDescriptionMetadata');
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return DownloadingMultiScaleImageEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/DownloadingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DownloadingMultiScaleImageEventArgsDescription } from "./DownloadingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let DownloadingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DownloadingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DownloadingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DownloadingMultiScaleImageEventArgsDescriptionMetadata.c(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.k(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            DownloadingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.ae("DownloadingMultiScaleImageEventArgs", () => new DownloadingMultiScaleImageEventArgsDescription());
            a.ad("DownloadingMultiScaleImageEventArgs", DownloadingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DownloadingMultiScaleImageEventArgsDescriptionMetadata, 'DownloadingMultiScaleImageEventArgsDescriptionMetadata');
    DownloadingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return DownloadingMultiScaleImageEventArgsDescriptionMetadata;
})();
